<ul class="nav nav-tabs">
    {tabs}
    <li {active}>
        <a href="{url}">{name}</a>
    </li>
    {/tabs}
</ul>
<div class="tab-pane">
    <iframe style="height:600px; width:100%" src="/assets/plugins/kcfinder/browse.php?type={type}&langCode={lang}"></iframe>
</div>
